@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import datetime
 import sys
-from typing import TYPE_CHECKING, ClassVar, Dict, List, Type
+from typing import TYPE_CHECKING, Annotated, ClassVar
 from uuid import UUID, uuid4
 
 import pytest
@@ -17,7 +17,7 @@ from litestar.testing import RequestFactory
 from litestar.typing import FieldDefinition
 from sqlalchemy import ForeignKey, func
 from sqlalchemy.orm import DeclarativeBase, Mapped, MappedAsDataclass, declared_attr, mapped_column, relationship
-from typing_extensions import Annotated, TypeVar
+from typing_extensions import TypeVar
 
 from advanced_alchemy.exceptions import ImproperConfigurationError
 from advanced_alchemy.extensions.litestar.dto import (
@@ -29,11 +29,11 @@ from advanced_alchemy.extensions.litestar.dto import (
 if TYPE_CHECKING:
     from collections.abc import Callable
     from types import ModuleType
-    from typing import Any, Dict, List, Type
+    from typing import Any
 
 
 @pytest.fixture(name="base")
-def fx_base() -> Type[DeclarativeBase]:
+def fx_base() -> type[DeclarativeBase]:
     class Base(DeclarativeBase):
         id: Mapped[UUID] = mapped_column(default=uuid4, primary_key=True)
         created: Mapped[datetime.datetime] = mapped_column(
@@ -55,7 +55,7 @@ def fx_base() -> Type[DeclarativeBase]:
 
 
 @pytest.fixture(name="author_model")
-def fx_author_model(base: DeclarativeBase) -> Type[DeclarativeBase]:
+def fx_author_model(base: DeclarativeBase) -> type[DeclarativeBase]:
     class Author(base):  # type: ignore
         name: Mapped[str]
         dob: Mapped[datetime.date]
@@ -81,7 +81,7 @@ DataT = TypeVar("DataT", bound=DeclarativeBase)
 
 
 async def get_model_from_dto(
-    dto_type: Type[SQLAlchemyDTO[DataT]],
+    dto_type: type[SQLAlchemyDTO[DataT]],
     annotation: Any,
     asgi_connection: Request[Any, Any, Any],
     raw: bytes,
@@ -97,12 +97,12 @@ async def get_model_from_dto(
     return dto_type(asgi_connection).decode_bytes(raw)
 
 
-def assert_model_values(model_instance: DeclarativeBase, expected_values: Dict[str, Any]) -> None:
+def assert_model_values(model_instance: DeclarativeBase, expected_values: dict[str, Any]) -> None:
     assert {k: v for k, v in model_instance.__dict__.items() if not k.startswith("_")} == expected_values
 
 
 async def test_model_write_dto(
-    author_model: Type[DeclarativeBase],
+    author_model: type[DeclarativeBase],
     raw_author: bytes,
     asgi_connection: Request[Any, Any, Any],
 ) -> None:
@@ -118,7 +118,7 @@ async def test_model_write_dto(
 
 
 async def test_model_read_dto(
-    author_model: Type[DeclarativeBase],
+    author_model: type[DeclarativeBase],
     raw_author: bytes,
     asgi_connection: Request[Any, Any, Any],
 ) -> None:
@@ -135,10 +135,10 @@ async def test_model_read_dto(
     )
 
 
-async def test_model_list_dto(author_model: Type[DeclarativeBase], asgi_connection: Request[Any, Any, Any]) -> None:
+async def test_model_list_dto(author_model: type[DeclarativeBase], asgi_connection: Request[Any, Any, Any]) -> None:
     dto_type = SQLAlchemyDTO[author_model]  # type: ignore
     raw = b'[{"id": "97108ac1-ffcb-411d-8b1e-d9183399f63b","name":"Agatha Christie","dob":"1890-09-15","created":"0001-01-01T00:00:00","updated":"0001-01-01T00:00:00"}]'
-    dto_data = await get_model_from_dto(dto_type, List[author_model], asgi_connection, raw)  # type: ignore
+    dto_data = await get_model_from_dto(dto_type, list[author_model], asgi_connection, raw)  # type: ignore
     assert isinstance(dto_data, list)
     assert_model_values(
         dto_data[0],  # type: ignore
@@ -151,7 +151,7 @@ async def test_model_list_dto(author_model: Type[DeclarativeBase], asgi_connecti
 
 
 async def test_dto_exclude(
-    author_model: Type[DeclarativeBase],
+    author_model: type[DeclarativeBase],
     raw_author: bytes,
     asgi_connection: Request[Any, Any, Any],
 ) -> None:
@@ -165,7 +165,7 @@ async def test_dto_exclude(
     assert "id" not in vars(model)
 
 
-async def test_write_dto_field_default(base: Type[DeclarativeBase], asgi_connection: Request[Any, Any, Any]) -> None:
+async def test_write_dto_field_default(base: type[DeclarativeBase], asgi_connection: Request[Any, Any, Any]) -> None:
     class Model(base):  # type: ignore
         field: Mapped[int] = mapped_column(default=3)
 
@@ -175,7 +175,7 @@ async def test_write_dto_field_default(base: Type[DeclarativeBase], asgi_connect
 
 
 async def test_write_dto_for_model_field_factory_default(
-    base: Type[DeclarativeBase],
+    base: type[DeclarativeBase],
     asgi_connection: Request[Any, Any, Any],
 ) -> None:
     val = uuid4()
@@ -189,7 +189,7 @@ async def test_write_dto_for_model_field_factory_default(
 
 
 async def test_dto_instrumented_attribute_key(
-    base: Type[DeclarativeBase],
+    base: type[DeclarativeBase],
     asgi_connection: Request[Any, Any, Any],
 ) -> None:
     val = uuid4()
@@ -203,7 +203,7 @@ async def test_dto_instrumented_attribute_key(
 
 
 async def test_write_dto_for_model_field_unsupported_default(
-    base: Type[DeclarativeBase],
+    base: type[DeclarativeBase],
     asgi_connection: Request[Any, Any, Any],
 ) -> None:
     """Test for error condition where we don't know what to do with a default
@@ -217,7 +217,7 @@ async def test_write_dto_for_model_field_unsupported_default(
 
 
 async def test_dto_for_private_model_field(
-    base: Type[DeclarativeBase],
+    base: type[DeclarativeBase],
     asgi_connection: Request[Any, Any, Any],
 ) -> None:
     class Model(base):  # type: ignore
@@ -242,7 +242,7 @@ async def test_dto_for_private_model_field(
 
 
 async def test_dto_for_non_mapped_model_field(
-    base: Type[DeclarativeBase],
+    base: type[DeclarativeBase],
     asgi_connection: Request[Any, Any, Any],
 ) -> None:
     class Model(base):  # type: ignore
@@ -254,7 +254,7 @@ async def test_dto_for_non_mapped_model_field(
 
 
 async def test_dto_mapped_as_dataclass_model_type(
-    base: Type[DeclarativeBase],
+    base: type[DeclarativeBase],
     asgi_connection: Request[Any, Any, Any],
 ) -> None:
     """Test declare pydantic type on `dto.DTOField`."""
@@ -269,7 +269,7 @@ async def test_dto_mapped_as_dataclass_model_type(
 
 
 async def test_to_mapped_model_with_collection_relationship(
-    base: Type[DeclarativeBase],
+    base: type[DeclarativeBase],
     create_module: Callable[[str], ModuleType],
     asgi_connection: Request[Any, Any, Any],
 ) -> None:
@@ -396,7 +396,7 @@ async def test_dto_mapped_union_type(
         """
 from __future__ import annotations
 
-from typing import Dict, List, Set, Tuple, Type, Union
+from typing import Dict, List, Set, Tuple, Type, Union, Optional
 
 from sqlalchemy import ForeignKey
 from sqlalchemy.orm import DeclarativeBase, Mapped, mapped_column
@@ -409,7 +409,7 @@ class Base(DeclarativeBase):
 
 class A(Base):
     __tablename__ = "a"
-    a: Mapped[str | None]
+    a: Mapped[Optional[str]]
 
 dto_type = SQLAlchemyDTO[A]
     """,
@@ -603,7 +603,7 @@ dto_type = SQLAlchemyDTO[A]
     assert vars(model)["c"] == [1, 2, 3]
 
 
-async def test_no_type_hint_column(base: Type[DeclarativeBase], asgi_connection: Request[Any, Any, Any]) -> None:
+async def test_no_type_hint_column(base: type[DeclarativeBase], asgi_connection: Request[Any, Any, Any]) -> None:
     class Model(base):  # type: ignore
         nullable_field = mapped_column(sqlalchemy.String)
         not_nullable_field = mapped_column(sqlalchemy.String, nullable=False, default="")
@@ -615,7 +615,7 @@ async def test_no_type_hint_column(base: Type[DeclarativeBase], asgi_connection:
 
 
 async def test_no_type_hint_scalar_relationship_with_nullable_fk(
-    base: Type[DeclarativeBase],
+    base: type[DeclarativeBase],
     asgi_connection: Request[Any, Any, Any],
 ) -> None:
     class Child(base):  # type: ignore
@@ -631,7 +631,7 @@ async def test_no_type_hint_scalar_relationship_with_nullable_fk(
 
 
 async def test_no_type_hint_scalar_relationship_with_not_nullable_fk(
-    base: Type[DeclarativeBase],
+    base: type[DeclarativeBase],
     asgi_connection: Request[Any, Any, Any],
 ) -> None:
     class Child(base):  # type: ignore
@@ -647,7 +647,7 @@ async def test_no_type_hint_scalar_relationship_with_not_nullable_fk(
 
 
 async def test_no_type_hint_collection_relationship(
-    base: Type[DeclarativeBase],
+    base: type[DeclarativeBase],
     asgi_connection: Request[Any, Any, Any],
 ) -> None:
     class Child(base):  # type: ignore
@@ -662,7 +662,7 @@ async def test_no_type_hint_collection_relationship(
 
 
 async def test_no_type_hint_collection_relationship_alt_collection_class(
-    base: Type[DeclarativeBase],
+    base: type[DeclarativeBase],
     asgi_connection: Request[Any, Any, Any],
 ) -> None:
     class Child(base):  # type: ignore
